# subfeature

[![zizmor](https://img.shields.io/badge/%F0%9F%8C%88-zizmor-white?labelColor=white)](https://zizmor.sh/)
[![CI](https://github.com/zizmorcore/zizmor/actions/workflows/ci.yml/badge.svg)](https://github.com/zizmorcore/zizmor/actions/workflows/ci.yml)
[![Crates.io](https://img.shields.io/crates/v/subfeature)](https://crates.io/crates/subfeature)
[![docs.rs](https://img.shields.io/docsrs/subfeature)](https://docs.rs/subfeature)
[![GitHub Sponsors](https://img.shields.io/github/sponsors/woodruffw?style=flat&logo=githubsponsors&labelColor=white&color=white)](https://github.com/sponsors/woodruffw)
[![Discord](https://img.shields.io/badge/Discord-%235865F2.svg?logo=discord&logoColor=white)](https://discord.com/invite/PGU3zGZuGG)

Subfeature handling and manipulation APIs.

A "subfeature" is a subset of a _feature_, which is zizmor's term for a
syntactically relevant extract of a YAML document. This crate provides
APIs for creating subfeatures and matching them against parent features.

This crate is part of [zizmor](https://zizmor.sh).

## License

MIT License.
